@@ -1,9 +1,9 @@
 
 .onAttach <- function(libname, pkgname) {
-  packageStartupMessage("lodGWAS library, version 1.0-0")
+  packageStartupMessage("lodGWAS library, version 1.0-6")
   packageStartupMessage("")
   packageStartupMessage("The user manual can be found in")
-  packageStartupMessage("'R/library/lodGWAS/doc'")
+  packageStartupMessage(system.file("doc", package = "lodGWAS"))
 }
 
 # FUNCTION INFORMATION COMPUTES THE IMPUTATION QUALITY SCORE OF THE SNP
